OC.L10N.register(
    "mail",
    {
    "Important" : "សំខាន់",
    "Work" : "ធ្វើការ",
    "Personal" : "ផ្ទាល់​ខ្លួន",
    "Mail" : "សំបុត្រ",
    "Save" : "រក្សាទុក",
    "Connect" : "ភ្ជាប់",
    "Name" : "ឈ្មោះ",
    "Password" : "ពាក្យសម្ងាត់",
    "None" : "គ្មាន",
    "Cancel" : "បោះបង់",
    "General" : "ទូទៅ",
    "Delete" : "លុប",
    "Search" : "Search",
    "Send" : "ផ្ញើ",
    "Choose" : "ជ្រើស",
    "Back" : "ត្រឡប់ក្រោយ",
    "Description" : "ការ​អធិប្បាយ",
    "Create" : "បង្កើត",
    "Select" : "Select",
    "Comment" : "មតិ",
    "Remove" : "ដកចេញ",
    "Other" : "ផ្សេងៗ",
    "Move" : "Move",
    "Rename" : "ប្ដូរ​ឈ្មោះ",
    "Reply" : "ឆ្លើយតប",
    "Add" : "បញ្ចូល",
    "Close" : "បិទ",
    "Date" : "កាលបរិច្ឆេទ",
    "Tags" : "ស្លាក",
    "All" : "ទាំងអស់",
    "Drafts" : "ពង្រាង",
    "Favorites" : "Favorites",
    "Inbox" : "ក្នុង​ប្រអប់សារ",
    "Junk" : "ព្រៃ",
    "Sent" : "ផ្ញើ",
    "Trash" : "ធុង​សំរាម"
},
"nplurals=1; plural=0;");
